
from setuptools import setup
setup (
    name="primul-pachet-Iustin-Muresanu",
    version="0.1.0",
    author="Iustin Muresanu",
    email="imuresanu@yahoo.com",
    packages=["my_own_package"],
    package_dir={"":"src\\"},
    include_package_data=True,
    description="primul meu pachet")





